@@ -6,25 +6,12 @@ from nltk.stem import WordNetLemmatizer, SnowballStemmer
 from nltk.stem.porter import *
 import numpy as np
 import nltk
-
-import os
-import word2vec
-from sklearn.feature_extraction.text import CountVectorizer
-import re
-import sys
-
-import random
-
-from numpy.linalg import norm
-
-from collections import namedtuple
-Segmentation = namedtuple('Segmentation',
-                          'total splits gains min_gain optimal')
-
+import nltk.stem as stemmer
 
 def lemmatize_stemming(text):
     return stemmer.stem(WordNetLemmatizer().lemmatize(text, pos='v'))
 
+
 def preprocess(text):
     result = []
     for token in gensim.utils.simple_preprocess(text):
@@ -33,8 +20,8 @@ def preprocess(text):
     return result
 
 
-def run(file_name):
-	start_segmentation(file_name)
+def run(file_name, word_vector_model):
+	start_segmentation(file_name, word_vector_model)
 	data = pd.read_csv('segmentaion_result.csv', error_bad_lines=False, encoding="utf8")
 	data_text = data[['text']]
 	data_text['index'] = data_text.index
@@ -96,15 +83,14 @@ def run(file_name):
 	f.write("Total "+str(no_gaps)+" Knowledge-gaps found!\n")
 
 ####################################################################################################################################
+import os
+import word2vec
+from sklearn.feature_extraction.text import CountVectorizer
+import re
+import sys
 
-def start_segmentation(book_path):
-    corpus_path = './text8'  
-    wrdvec_path = 'wrdvecs-text8.bin'
-
-    if not os.path.exists(wrdvec_path):
-        word2vec.word2vec(corpus_path, wrdvec_path, cbow=1, iter_=5, hs=1, threads=4, sample='1e-5', window=15, size=200, binary=1)
-
-    model = word2vec.load(wrdvec_path)
+def start_segmentation(book_path, word_vector_model):
+    model = word2vec.load(word_vector_model)
     wrdvecs = pd.DataFrame(model.vectors, index=model.vocab)
     del model
     print(wrdvecs.shape)
@@ -156,6 +142,10 @@ def start_segmentation(book_path):
     print('ratio of scores %5.4f' % (totals[0] / totals[1]))
 
 #########################################################################################################################################
+import random
+from numpy.linalg import norm
+from collections import namedtuple
+Segmentation = namedtuple('Segmentation', 'total splits gains min_gain optimal')
 
 def get_segments(text_particles, segmentation):
     segmented_text = []
